package cn.estsh.i3plus.pojo.wms.bean;


import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.base.enumutil.WmsEnumUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.ColumnDefault;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.persistence.Version;

/**
 * @Description : 车辆信息明细
 * @Reference :
 * @Author : qianhuasheng
 * @CreateDate : 2019-12-06 15:58
 * @Modify:
 **/
@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Table(name="WMS_TMS_SHIPPING_EXT_DETAIL")
@Api("装车单信息明细")
public class WmsTmsShippingExtDetail extends BaseBean {
	private static final long serialVersionUID = -4800308354250386102L;

	@Column(name="MOVE_NO")
	@ApiParam("装车单")
	public String moveNo;

	@Column(name = "PART_NO")
	@ApiParam("物料编码")
	public String partNo;

	@Column(name = "PART_NAME_RDD")
	@ApiParam("物料名称")
	public String partNameRdd;

	@Column(name = "ITEM")
	@ApiParam("行号")
	public String item;

	@Column(name = "QTY", columnDefinition = "decimal(18,8)")
	@ColumnDefault("0")
	@ApiParam(value = "需求数量", example = "0")
	public Double qty;

	@Column(name = "UNIT")
	@ApiParam("单位")
	public String unit;

	@Column(name = "ORDER_NO")
	@ApiParam("订单号")
	public String orderNo;

	@Column(name = "SRC_WH_NO")
	@ApiParam("源仓库代码")
	public String srcWhNo;

	@Column(name = "SRC_ZONE_NO")
	@ApiParam("源存储区代码")
	public String srcZoneNo;

	@Column(name = "SRC_LOCATE_NO")
	@ApiParam("源库位代码")
	public String srcLocateNo;

	@Column(name = "DEST_WH_NO")
	@ApiParam("目标仓库代码")
	public String destWhNo;

	@Column(name = "DEST_ZONE_NO")
	@ApiParam("目标存储区代码")
	public String destZoneNo;

	@Column(name = "DEST_LOCATE_NO")
	@ApiParam("目标库位代码")
	public String destLocateNo;

	@Column(name = "PRINT_QTY", columnDefinition = "decimal(18,8)")
	@ColumnDefault("0")
	@ApiParam(value = "条码打印数量", example = "1")
	private Double printQty;

	@Column(name = "PLAN_DATE")
	@ApiParam(value = "计划日期")
	private String planDate;

	@Column(name = "PLAN_TIME")
	@ApiParam(value = "计划时间")
	private String planTime;

	@Column(name = "SRC_NO")
	@ApiParam(value = "源单号")
	private String srcNo;
	/**
	 * 状态:N=正常,C=行取消
	 */
	@Column(name = "ITEM_STATUS")
	@ApiParam(value = "状态", example = "1")
	@AnnoOutputColumn(refClass = WmsEnumUtil.ORDER_DETAILS_STATUS.class, refForeignKey = "value", value = "description")
	private Integer itemStatus;

	/**
	 * 是否免费:0=计费,1=免费
	 */
	@Column(name = "IS_FREE")
	@ApiParam(value = "是否免费", example = "1")
	@AnnoOutputColumn(refClass = WmsEnumUtil.TRUE_OR_FALSE.class, refForeignKey = "value", value = "description")
	public Integer isFree;

	@Column(name = "REMARK")
	@ApiParam(value = "操作原因")
	private String remark;

	@Column(name = "PICK_QTY", columnDefinition = "decimal(18,8)")
	@ColumnDefault("0")
	@ApiParam(value = "已拣货数量", example = "1")
	private Double pickQty;

	@Column(name = "OUT_QTY", columnDefinition = "decimal(18,8)")
	@ColumnDefault("0")
	@ApiParam(value = "已出库数量", example = "1")
	private Double outQty;

	@Column(name = "REC_QTY", columnDefinition = "decimal(18,8)")
	@ColumnDefault("0")
	@ApiParam(value = "已收货数量", example = "1")
	private Double recQty;

	@Column(name = "MOVE_QTY", columnDefinition = "decimal(18,8)")
	@ColumnDefault("0")
	@ApiParam(value = "已移库数量", example = "1")
	private Double moveQty;

	@Column(name = "TASK_GENERATE_QTY", columnDefinition = "decimal(18,8)")
	@ColumnDefault("0")
	@ApiParam(value = "任务生成数量", example = "1")
	private Double taskGenerateQty;

	@Column(name = "SRC_AREA_NO")
	@ApiParam("源库存地代码")
	public String srcAreaNo;

	@Column(name = "DEST_AREA_NO")
	@ApiParam("目的库存地代码")
	public String destAreaNo;

	@Column(name = "LOT_NO")
	@ApiParam("批次")
	public String lotNo;

	@Column(name="SRC_ITEM", columnDefinition="varchar(50) default ''",nullable=false)
	@ApiParam("源单行号")
	public String srcItem;

	@Column(name = "CUST_ORDER_NO")
	@ApiParam("客户订单号")
	public String custOrderNo;

	@Column(name = "ASSIGN_DATE_CODE")
	@ApiParam(value = "指定生产日期")
	private String assignDateCode;

	@Transient
	@ApiParam("实际批次")
	private String actualLot;

	@Transient
	@ApiParam("实际数量")
	private Double actualQty;

	@Transient
	@ApiParam("推荐批次")
	private String recommondLot;

	@Transient
	@ApiParam("推荐库位")
	private String recommondLocateNo;

	@Transient
	@ApiParam("前端表格编辑使用")
	private Boolean isSet = false;

	@Transient
	@ApiParam("生产日期")
	public String dateCode;

	@ApiParam(value = "散件移库输入移库数量")
	@Transient
	public Double inputMoveQty;

	@Transient
	@ApiParam(value = "标准包装", example = "1")
	private Double snp;

	@Transient
	@ApiParam(value = "条码总数量", example = "1")
	private Double detailsSnCount;

	@Transient
	@ApiParam(value = "余数", example = "1")
	private Double restQty;

	@Transient
	@ApiParam("任务状态")
	@AnnoOutputColumn(refClass = WmsEnumUtil.IS_GENERAL_TASK.class, refForeignKey = "value", value = "description")
	private Integer isTask;

	@Transient
	@ApiParam("主表单据状态")
	@AnnoOutputColumn(refClass = WmsEnumUtil.MASTER_ORDER_STATUS.class, refForeignKey = "value", value = "description")
	private Integer orderMasterStatus;

	@Transient
	@ApiParam("打印状态")
	@AnnoOutputColumn(refClass = WmsEnumUtil.PRINT_STATUS.class, refForeignKey = "value", value = "description")
	private Integer printStatus;

	@Transient
	@ApiParam("优先级")
	private Integer priority;

	@Transient
	@ApiParam(value = "汇总需求数量", example = "0")
	public Double sumQty;

	@Transient
	@ApiParam(value = "汇总拣货数量", example = "0")
	public Double sumPickQty;

	@Transient
	@ApiParam("执行状态")
	@AnnoOutputColumn(refClass = WmsEnumUtil.PICKING_EXECUTE_STATUS.class, refForeignKey = "value", value = "description")
	private Integer executeStatus;

	@Version
	@Column(name = "LOCK_VERSION")
	@ApiParam(value = "乐观锁", example = "1")
	public transient Integer lockVersion;

	@Transient
	@ApiParam("移动类型")
	public Integer moveType;

	@Transient
	@ApiParam("业务类型")
	@AnnoOutputColumn(refClass = WmsEnumUtil.OUT_MOVEMENT_BUSI_TYPE.class, refForeignKey = "value", value = "description")
	public Integer busiType;

	@Column(name = "IS_SN")
	@ApiParam(value = "条码生成状态", example = "20")
	public Integer isSn;


	public WmsTmsShippingExtDetail () {

	}


	public String getRecommondLot() {
		return recommondLot == null ? "无" : this.recommondLot;
	}

	public Double getQty() {
		return qty == null ? 0D : this.qty.doubleValue();
	}

	public Double getOutQty() {
		return outQty == null ? 0D : this.outQty.doubleValue();
	}

	public Double getPickQty() {
		return pickQty == null ? 0D : this.pickQty.doubleValue();
	}

	public Double getActualQty() {
		return actualQty == null ? 0D : this.actualQty.doubleValue();
	}

	public Double getRecQty() {
		return recQty == null ? 0D : this.recQty.doubleValue();
	}

	public Integer getIsTaskVal() {
		return isTask == null ? 0 : this.isTask.intValue();
	}

	public Integer getOrderMasterStatus() {
		return orderMasterStatus == null ? 0 : this.orderMasterStatus.intValue();
	}

	public WmsTmsShippingExtDetail(WmsDocMovementDetails docMovementDetails,String moveNo) {
		this.moveNo = moveNo;
		this.partNo = docMovementDetails.getPartNo();
		this.partNameRdd = docMovementDetails.getPartNameRdd();
		this.item = docMovementDetails.getItem();
		this.qty =docMovementDetails.getQty();
		this.unit = docMovementDetails.getUnit();
		this.orderNo = docMovementDetails.getOrderNo();
		this.srcWhNo = docMovementDetails.getSrcWhNo();
		this.srcZoneNo = docMovementDetails.getSrcZoneNo();
		this.srcLocateNo = docMovementDetails.getSrcLocateNo();
		this.destWhNo = docMovementDetails.getDestWhNo();
		this.destZoneNo = docMovementDetails.getDestZoneNo();
		this.destLocateNo = docMovementDetails.getDestLocateNo();
		this.printQty = docMovementDetails.getPrintQty();
		this.planDate = docMovementDetails.getPlanDate();
		this.planTime = docMovementDetails.getPlanTime();
		this.srcNo = docMovementDetails.getSrcNo();
		this.itemStatus = docMovementDetails.getItemStatus();
		this.isFree = docMovementDetails.getIsFree();
		this.remark = docMovementDetails.getRemark();
		this.pickQty = docMovementDetails.getPickQty();
		this.outQty = docMovementDetails.getOutQty();
		this.recQty = docMovementDetails.getRecQty();
		this.moveQty = docMovementDetails.getMoveQty();
		this.taskGenerateQty = docMovementDetails.getTaskGenerateQty();
		this.srcAreaNo = docMovementDetails.getSrcAreaNo();
		this.destAreaNo = docMovementDetails.getDestAreaNo();
		this.lotNo = docMovementDetails.getLotNo();
		this.srcItem = docMovementDetails.getSrcItem();
		this.custOrderNo = docMovementDetails.getCustOrderNo();
		this.assignDateCode = docMovementDetails.getAssignDateCode();
		this.actualLot = docMovementDetails.getActualLot();
		this.actualQty = docMovementDetails.getActualQty();
		this.recommondLot = docMovementDetails.getRecommondLot();
		this.recommondLocateNo = docMovementDetails.getRecommondLocateNo();
		this.isSet = docMovementDetails.getIsSet();
		this.dateCode = docMovementDetails.getDateCode();
		this.inputMoveQty = docMovementDetails.getInputMoveQty();
		this.snp = docMovementDetails.getSnp();
		this.detailsSnCount = docMovementDetails.getDetailsSnCount();
		this.restQty = docMovementDetails.getRestQty();
		this.isTask = docMovementDetails.getIsTask();
		this.orderMasterStatus = docMovementDetails.getOrderMasterStatus();
		this.printStatus = docMovementDetails.getPrintStatus();
		this.priority = docMovementDetails.getPriority();
		this.sumQty = docMovementDetails.getSumQty();
		this.sumPickQty = docMovementDetails.getSumPickQty();
		this.executeStatus = docMovementDetails.getExecuteStatus();
		this.lockVersion = docMovementDetails.getLockVersion();
		this.moveType = docMovementDetails.getMoveType();
		this.busiType = docMovementDetails.getBusiType();
		this.isSn = docMovementDetails.getIsSn();
	}
}
