package cn.estsh.i3plus.pojo.wms.bean;


import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.base.enumutil.WmsEnumUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.ColumnDefault;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Table;
import javax.persistence.Transient;

/**
 * @Description : 车辆信息明细
 * @Reference :
 * @Author : qianhuasheng
 * @CreateDate : 2019-12-06 15:58
 * @Modify:
 **/
@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Table(name="WMS_TMS_SHIPPING_EXT_SN")
@Api("装车单条码明细")
public class WmsTmsShippingExtSn extends BaseBean {

    private static final long serialVersionUID = 5704546384179442907L;

    @Column(name="MOVE_NO")
    @ApiParam("装车单")
    public String moveNo;

    @Column(name="ORDER_NO")
    @ApiParam("订单号")
    public String orderNo;

    @Column(name="ITEM")
    @ApiParam("行号")
    public String item;

    @Column(name="PART_NO")
    @ApiParam("物料编码")
    public String partNo;

    @Column(name="PART_NAME_RDD")
    @ApiParam("物料名称")
    public String partNameRdd;

    @Column(name="QTY", columnDefinition = "decimal(18,8)")
    @ColumnDefault("0")
    @ApiParam(value = "数量", example = "0")
    public Double qty;


    @Column(name="UNIT")
    @ApiParam("单位")
    public String unit;

    /**
     * 状态：操作状态  itemStatus
     */
    @Column(name="SN_STATUS")
    @ApiParam(value = "操作状态", example = "10")
    @AnnoOutputColumn(refClass = WmsEnumUtil.ORDER_SN_STATUS.class,refForeignKey = "value",value = "description")
    public Integer snStatus;

    @Column(name="SN")
    @ApiParam("条码")
    public String sn;

    @Column(name = "VENDOR_NO")
    @ApiParam(value = "供应商编码")
    public String vendorNo;

    @Column(name = "SN_TYPE")
    @ApiParam(value = "条码类型")
    @AnnoOutputColumn(refClass = WmsEnumUtil.WMS_STOCK_TYPE.class, refForeignKey = "value", value = "description")
    private Integer snType;

    @Transient
    @ApiParam("前端表格编辑使用")
    private Boolean isSet = false;

    @Transient
    @ApiParam("目标库位代码")
    public String destLocateNo;

    @Transient
    @ApiParam("源库位代码")
    public String srcLocateNo;

    @Transient
    @ApiParam("生产日期")
    public String dateCode;

    @ApiParam(value = "散件移库输入移库数量")
    @Transient
    public Double inputMoveQty;

    @Transient
    @ApiParam("计划交货日期")
    private String planDate;

    @Transient
    @ApiParam("计划交货时间")
    private String planTime;

    @Transient
    @ApiParam("ERP库存地")
    private String erpWhNo;

    @Transient
    @AnnoOutputColumn(refClass = WmsEnumUtil.STOCK_SN_STATUS.class,refForeignKey = "value",value = "description")
    public Integer itemStatus;

    @Transient
    @ApiParam("客户零件号")
    private String customerPartNo;

    @Transient
    @ApiParam("父层级packcode对应的可回用零件号")
    private String parentReturnPart;


    @Transient
    @ApiParam("打印模板")
    private String templateNo;

    @Transient
    @ApiParam("剩余箱数量")
    private Long countBox;

    public WmsTmsShippingExtSn(){}

    public WmsTmsShippingExtSn(Long countBox,String partNo) {
        this.countBox = countBox;
        this.partNo = partNo;
    }

    public WmsTmsShippingExtSn(String moveNo,WmsDocMovementSn docMovementSn) {
        this.moveNo = moveNo;
        this.orderNo  = docMovementSn.getOrderNo();
        this.item  = docMovementSn.getItem();
        this.partNo  = docMovementSn.getPartNo();
        this.partNameRdd  = docMovementSn.getPartNameRdd();
        this.qty  = docMovementSn.getQty();
        this.unit  = docMovementSn.getUnit();
        this.snStatus  = docMovementSn.getSnStatus();
        this.sn  = docMovementSn.getSn();
        this.vendorNo  = docMovementSn.getVendorNo();
        this.snType  = docMovementSn.getSnType();
        this.isSet  = docMovementSn.getIsSet();
        this.destLocateNo  = docMovementSn.getDestLocateNo();
        this.srcLocateNo  = docMovementSn.getSrcLocateNo();
        this.dateCode  = docMovementSn.getDateCode();
        this.inputMoveQty  = docMovementSn.getInputMoveQty();
        this.planDate  = docMovementSn.getPlanDate();
        this.planTime  = docMovementSn.getPlanTime();
        this.erpWhNo  = docMovementSn.getErpWhNo();
        this.itemStatus  = docMovementSn.getItemStatus();
        this.customerPartNo  = docMovementSn.getCustomerPartNo();
        this.parentReturnPart  = docMovementSn.getParentReturnPart();
        this.templateNo  = docMovementSn.getTemplateNo();
        this.countBox  = docMovementSn.getCountBox();
    }
}
